#
# spec file for package bazel-gazelle
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global provider        github
%global provider_tld    com
%global project         bazelbuild
%global repo            bazel-gazelle
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}

%define src_install_dir /usr/src/%{name}

Name:           bazel-gazelle
Version:        0.19.0
Release:        lp152.1.4
Summary:        Generator of Bazel build files for Go projects
License:        Apache-2.0
Url:            https://github.com/bazelbuild/bazel-gazelle
Source:         %{name}-%{version}.tar.xz
BuildRequires:  golang-packaging
BuildRequires:  golang(API) >= 1.10
%{go_provides}

%description
Gazelle is a generator of Bazel build files for Go projects. It can create new
BUILD.bazel files for a project that follows "go build" conventions, and it can
update existing build files to include new sources, dependencies, and options.
Gazelle may be run by Bazel using the gazelle rule, or it can be run as a
command line tool. Gazelle can also be run in an external repository as part of
the go_repository rule. Gazelle may be extended to support new languages and
custom rule sets.

%package source
Summary:        Source code of bazel-gazelle
BuildArch:      noarch

%description source
Gazelle is a generator of Bazel build files for Go projects. It can create new
BUILD.bazel files for a project that follows "go build" conventions, and it can
update existing build files to include new sources, dependencies, and options.
Gazelle may be run by Bazel using the gazelle rule, or it can be run as a
command line tool. Gazelle can also be run in an external repository as part of
the go_repository rule. Gazelle may be extended to support new languages and
custom rule sets.

This package contains source code for Gazelle.

%prep
%setup -q
rm -f ./go.mod ./go.sum

%build
%goprep %{provider_prefix}
%gobuild cmd/gazelle

%install
%goinstall

mkdir -p %{buildroot}%{src_install_dir}
tar -xJf %{SOURCE0} --strip-components=1 -C %{buildroot}%{src_install_dir}

%files
%license LICENSE
%doc README.rst
%{_bindir}/gazelle

%files source
%{src_install_dir}

%changelog
* Tue Dec 17 2019 mrostecki@opensuse.org
- Update to version 0.19.0:
  * Update to rules_go v0.20.0 (#660)
  * Export IsStandard (#659)
  * Update language/go/std_package_list.go (#658)
  * go_repository should correctly identify build files and respect build_file_name (#655)
  * Update known proto dependency resolution tables (#653)
  * repo: repository directive (#651)
  * Allow passing additional visibility to internal packages (#649)
  * language/go: simpler submodule visibility (#648)
  * repo, language/go: refactor Go-specific functionality out of repo (#647)
  * Update boilerplate for rules_go v0.19.4 [skip ci] (#645)
  * Revert "language/go, go_repository: submodule visibility (#637)" (#641)
  * Excluding consumed generated files from go_library (#643)
  * Making resolveGo public (#642)
  * language/go, go_repository: submodule visibility (#637)
  * rule: add BzlExprValue interface and make PlatformStrings use it (#636)
  * Update boilerplate for rules_go 0.19.4 [skip ci] (#633)
  * go_repository: add go_repository_config for caching relevant repo config (#615)
  * Update boilerplate for gazelle 0.18.2 [skip ci] (#628)
  * autogazelle: use default syntax for expanding $1 (#627)
  * gazelle_binary: set package name to 'main' in GoLibrary (#625)
  * Add iOS platform and OS aliases (#612)
  * Fix update-repos -build_tags documentation [ci skip] (#624)
  * repo: add version/commit select for update-repos (#595)
  * Update rules_go boilerplate to 0.19.3 [skip ci] (#621)
  * Update rules_go boilerplate [skip ci] (#620)
  * Rewrite README intro to be less Go-specific [skip ci] (#618)
  * Add issue template [skip ci] (#617)
  * Upgrade github.com/bazelbuild/buildtools to latest (#608)
  * go_repository takes Gazelle directives (#603)
  * Read module attributes from macro for remote cache (#589)
  * Make CI pass on Windows (#606)
  * go_repository: don't assume PATH is set (#601)
  * fixed an error message (#596)
  * Update rules_go boilerplate for 0.19.1 [skip ci] (#593)
  * Supress stderr from fetchrepo if successful (#590)
  * Update boilerplate for 0.18.1 [skip ci] (#588)
  * Create Bazel CI configuration file (#587)
  * go_repository: don't check tools source list on windows (#586)
  * Announce release 0.18.0 [skip ci] (#585)
  * Update known protos, consistent with rules_go 0.19.0 (#584)
  * update-repos: add or update repositories in module mode (#583)
  * go_repository_tools: use generated file with list of srcs (#582)
  * Update to rules_go 0.19.0 (#581)
  * go_repository: respect proxy and sumdb privacy environment variables (#580)
  * Update rules_go boilerplate [skip ci] (#577)
  * rules_go 0.18.7 (#573)
  * Fix go_repository rule when using urls (#572)
  * language/go: implement minimal module compatibility (#564)
  * Update rules_go to master as of 2019-06-28 (#563)
  * Fix go_repository configuration (#559)
  * Update rules_go + other changes (#558)
  * Document community extensions [skip ci] (#554)
  * go_repository: read configuration from main WORKSPACE (#550)
  * Fix typo (#552)
  * correct mistakes of comment (#548)
  * Update boilerplate for rules_go 0.18.6 [skip ci] (#544)
  * map_kind: fix bug in merging loads for multiple mappings (#541)
  * Detect BUILD files after fetching the repo (#538)
  * GO_REPOSITORY_USE_HOST_CACHE enables a shared mod cache (#535)
  * [go] Respect go_proto_library rules generated by another plugin (#530)
  * Use external dependencies instead of vendor directory (#534)
  * go_repository: don't require a repository named "go_sdk" (#532)
  * Improve error logging for go_repository (#526)
  * Update boilerplate for rules_go 0.18.5 [skip ci] (#527)
  * Don't override modules with replace directives (#524)
  * repo: add unstable comment (#523)
  * go_repository: print stderr, even on success (#522)
  * Add support for pruning unneeded rules to update-repos (#514)
  * Update rules_go boilerplate [skip ci] (#520)
  * go_repository: Support GIT_SSH and GIT_SSH_COMMAND env vars (#519)
  * language/go: fix typo s|compiler_plugin|compiler/plugin| in wkt map (#517)
  * Add support for the replace directive in go.mod  (#512)
  * go_repository: replace attribute (#502)
  * Use findGoTool() for "go list" (#501)
  * repository_macro directive for referencing macros from WORKSPACE (#493)
  * Update boilerplate for rules_go 0.18.3 [skip ci] (#495)
  * Update boilerplate for rules_go 0.18.2 [skip ci] (#494)
  * Upgrade github.com/bazelbuild/buildtools to latest (#492)
  * Add -to_macro option to update-repos (#480)
  * Support lowercase version of *_proxy env vars (#487)
  * language/go: experimental module mode (#484)
  * build_extra_args should be a list (#481)
  * Update boilerplate for rules_go releases [skip ci] (#482)
  * Clarifies "ambiguous import" message (#479)
  * walk: allow "# gazelle:exclude ." (#474)
  * Fix invisible directive table (#476)
  * map_kind directive: fix bug in handling of packages lacking a BUILD file (#471)
  * Update boilerplate for rules_go 0.18.0 [skip ci] (#468)
  * update-repos: import modules in module mode (#467)
  * go mod tidy (#466)
  * go_repository: support modules (#450)
  * Update boilerplate for Gazelle 0.17.0 [skip ci] (#464)
* Thu Nov 21 2019 mrostecki@opensuse.org
- Update to version 0.17.0:
  * Update to rules_go 0.17.1 and bazel 0.23.0 (#462)
  * proto/generate: fix inclusion of generated files in proto_library targets (#455)
  * gazelle:map_kind directive (#448)
  * Update README boilerplate for rules_go 0.17.1 [skip ci] (#459)
  * Add build options to update-repos (#447)
  * Add t.Helper() to all the testtools helper methods (#451)
  * Merge hasDefaultVisibility and checkInternalVisibility functions (#446)
  * Add support for specifying alternative protobuf and gRPC compilers. (#428)
  * fixed error message (#444)
  * language/go: special case for github.com/golang/protobuf/proto (#443)
  * cmd/move_labels: remove workaround for LoadStmt (#442)
  * Use nogo with vet = True (#439)
  * Support proto_strip_import_prefix and proto_import_prefix (#434)
  * repo: support for importing godep (#431)
  * Update boilerplate in README for rules_go 0.17.0 (#435)
  * Load rules_go workspace definitions from deps.bzl (#433)
  * Upgrade dependencies (#430)
  * Add ability to update proto.csv by results of the bazel query. (#426)
  * Update known proto imports for Google APIs (#424)
  * Exit error status 1 when diff and run in diff mode (#421)
  * go_repository: set GOCACHE when building fetch_repo and gazelle (#419)
  * repo: There are three go pseudoversion formats (#418)
  * Include hidden directories during walking (#415)
  * language/go: resolve missing imports under current prefix as external (#409)
  * cmd/gazelle: save configurations for dependency resolution (#413)
  * repo: populate vcs field when importing Gopkg.lock with source (#410)
  * correct strip_prefix call in go_repository example (#408)
  * Update boilerplate for 0.16.0 [skip ci] (#406)
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Tue Jan  8 2019 Michał Rostecki <mrostecki@suse.de>
- Initial version 0.16.0
